pyesmda.approximate\_covariance\_matrix\_from\_ensembles
========================================================

.. currentmodule:: pyesmda

.. autofunction:: approximate_covariance_matrix_from_ensembles